@@ -25,10 +25,11 @@ class TrainerTestCase(unittest.TestCase):
                               eval_interval=100,
                               log_interval=50,
                               experiment_name='glm_large',
-                              pytorch_device='cpu',
+                              pytorch_device='cuda',
                               load_dir=None,
+                              fp16=True,
                               lr=1e-4,
-                              save_epoch=10)
+                              save_interval=10)
             print("downloading...")
 
             cl_args = CollateArguments()
@@ -64,7 +65,7 @@ class TrainerTestCase(unittest.TestCase):
                                              dataset_type='dev',
                                              tokenizer=tokenizer)
             valid_dataset.example_list = valid_dataset.example_list[:1]
-
+            print(task_name)
             metric_methods = DEFAULT_METRICS[task_name]
             trainer.train(model,
                           collate_fn=collate_fn,
